"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.i18nVue = exports.trans_choice = exports.reset = exports.getActiveLanguage = exports.transChoice = exports.trans = exports.loadLanguageAsync = void 0;
var vue_1 = require("vue");
var pluralization_1 = require("./pluralization");
var isServer = typeof window === 'undefined';
/**
 * The default options, for the plugin.
 */
var DEFAULT_OPTIONS = {
    lang: !isServer && document.documentElement.lang ? document.documentElement.lang.replace('-', '_') : 'en',
    resolve: function (lang) { return new Promise(function (resolve) { return resolve({ default: {} }); }); },
};
/**
 * Stores the current options.
 */
var options = DEFAULT_OPTIONS;
/**
 * Stores the loaded languages.
 */
var loaded = [];
/**
 * The active messages to use.
 */
var activeMessages = (0, vue_1.reactive)({});
/**
 * Loads the language file.
 */
function loadLanguageAsync(lang) {
    lang = lang.replace('-', '_');
    var loadedLang = loaded.find(function (row) { return row.lang === lang; });
    if (loadedLang) {
        return Promise.resolve(setLanguage(loadedLang));
    }
    return options
        .resolve(lang)
        .then(function (_a) {
        var messages = _a.default;
        var data = { lang: lang, messages: messages };
        loaded.push(data);
        return setLanguage(data);
    })
        .catch(function (err) {
        throw new TypeError("Cannot load lang: ".concat(lang, " file: ").concat(err.message));
    });
}
exports.loadLanguageAsync = loadLanguageAsync;
/**
 * Get the translation for the given key.
 */
function trans(key, replacements) {
    if (replacements === void 0) { replacements = {}; }
    if (!activeMessages[key]) {
        activeMessages[key] = key;
    }
    return makeReplacements(activeMessages[key], replacements);
}
exports.trans = trans;
/**
 * Translates the given message based on a count.
 */
function transChoice(key, number, replacements) {
    if (replacements === void 0) { replacements = {}; }
    var message = trans(key, replacements);
    replacements.count = number.toString();
    return makeReplacements((0, pluralization_1.choose)(message, number, options.lang), replacements);
}
exports.transChoice = transChoice;
/**
 * Returns the current active language.
 */
function getActiveLanguage() {
    return options.lang;
}
exports.getActiveLanguage = getActiveLanguage;
/**
 * Sets the language messages to the activeMessages.
 */
function setLanguage(_a) {
    var lang = _a.lang, messages = _a.messages;
    if (!isServer) {
        document.querySelector('html').setAttribute('lang', lang);
    }
    options.lang = lang;
    for (var _i = 0, _b = Object.entries(messages); _i < _b.length; _i++) {
        var _c = _b[_i], key = _c[0], value = _c[1];
        activeMessages[key] = value;
    }
    for (var _d = 0, _e = Object.entries(activeMessages); _d < _e.length; _d++) {
        var key = _e[_d][0];
        if (!messages[key]) {
            activeMessages[key] = null;
        }
    }
    return lang;
}
/**
 * Make the place-holder replacements on a line.
 */
function makeReplacements(message, replacements) {
    var capitalize = function (s) { return s.charAt(0).toUpperCase() + s.slice(1); };
    Object.entries(replacements || []).forEach(function (_a) {
        var key = _a[0], value = _a[1];
        value = value.toString();
        message = message
            .replace(":".concat(key), value)
            .replace(":".concat(key.toUpperCase()), value.toUpperCase())
            .replace(":".concat(capitalize(key)), capitalize(value));
    });
    return message;
}
/**
 * Resets all the data stored in memory.
 */
var reset = function () {
    loaded = [];
    options = DEFAULT_OPTIONS;
    for (var _i = 0, _a = Object.entries(activeMessages); _i < _a.length; _i++) {
        var key = _a[_i][0];
        activeMessages[key] = null;
    }
};
exports.reset = reset;
/**
 * Alias to `transChoice` to mimic the same function name from Laravel Framework.
 */
exports.trans_choice = transChoice;
/**
 * The Vue Plugin. to be used on your Vue app like this: `app.use(i18nVue)`
 */
exports.i18nVue = {
    install: function (app, currentOptions) {
        if (currentOptions === void 0) { currentOptions = {}; }
        options = __assign(__assign({}, options), currentOptions);
        app.config.globalProperties.$t = function (key, replacements) { return trans(key, replacements); };
        app.config.globalProperties.$tChoice = function (key, number, replacements) {
            return transChoice(key, number, replacements);
        };
        loadLanguageAsync(options.lang);
    }
};
//# sourceMappingURL=index.js.map