"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.choose = void 0;
var get_plural_index_1 = require("./utils/get-plural-index");
/**
 * Select a proper translation string based on the given number.
 */
function choose(message, number, lang) {
    var segments = message.split('|');
    var extracted = extract(segments, number);
    if (extracted !== null) {
        return extracted.trim();
    }
    segments = stripConditions(segments);
    var pluralIndex = (0, get_plural_index_1.getPluralIndex)(lang, number);
    if (segments.length === 1 || !segments[pluralIndex]) {
        return segments[0];
    }
    return segments[pluralIndex];
}
exports.choose = choose;
/**
 * Extract a translation string using inline conditions.
 */
function extract(segments, number) {
    for (var _i = 0, segments_1 = segments; _i < segments_1.length; _i++) {
        var part = segments_1[_i];
        var line = extractFromString(part, number);
        if (line !== null) {
            return line;
        }
    }
    return null;
}
/**
 * Get the translation string if the condition matches.
 */
function extractFromString(part, number) {
    var matches = part.match(/^[\{\[]([^\[\]\{\}]*)[\}\]](.*)/s) || [];
    if (matches.length !== 3) {
        return null;
    }
    var condition = matches[1];
    var value = matches[2];
    if (condition.includes(',')) {
        var _a = condition.split(','), from = _a[0], to = _a[1];
        if (to === '*' && number >= parseFloat(from)) {
            return value;
        }
        else if (from === '*' && number <= parseFloat(to)) {
            return value;
        }
        else if (number >= parseFloat(from) && number <= parseFloat(to)) {
            return value;
        }
    }
    return parseFloat(condition) === number ? value : null;
}
/**
 * Strip the inline conditions from each segment, just leaving the text.
 */
function stripConditions(segments) {
    return segments.map(function (part) { return part.replace(/^[\{\[]([^\[\]\{\}]*)[\}\]]/, ''); });
}
//# sourceMappingURL=pluralization.js.map